package	jp.co.sds_corp.nanchart.graph;

import java.awt.Rectangle;
import java.util.Iterator;
import java.util.Map;
import java.util.SortedMap;

/**
GraphStorageインターフェースは、グラフのデータ格納クラスオブジェクトの定義を提供します。
<BR>
データ格納クラスに格納されるデータは、{@link Comparable}インターフェースを
実装している必要があります。また、実際のデータは{@link Number}クラスの
サブクラスや{@link jp.co.sds_corp.util.common.CmnDate}クラス等でも格納できますが、
{@link #getXPos(Rectangle,Object,Object)}と
{@link #getYPos(Rectangle,Object,Object)}
メソッドにより格納されている値を座標の値に変換できなくてはなりません。
<BR>
このクラスは、{@link GraphSeries}クラスに格納されます。
@see	GraphSeries
@see	Value
*/
public interface GraphStorage extends SortedMap
{
	/**
	* X軸の範囲を設定します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	*/
	public void setXRange( Object xMin, Object xMax );

	/**
	* Y軸の範囲を設定します。
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public void setYRange( Object yMin, Object yMax );

	/**
	* 格納されているデータから、X軸の範囲を設定します。
	*/
	public void setXRange();

	/**
	* 格納されているデータから、Y軸の範囲を設定します。
	*/
	public void setYRange();

	/**
	* 格納されているデータから、X軸・Y軸の範囲を設定します。
	*/
	public void setRange();

	/**
	* X軸の最大値を取得します。
	* @return	X軸の最大値
	*/
	public Object getXMax();

	/**
	* X軸の最小値を取得します。
	* @return	X軸の最小値
	*/
	public Object getXMin();

	/**
	* X軸の値を座標値に変換します。
	* @param	rect	全体の幅
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	* @return	座標値
	*/
	public double getXPos( Rectangle rect, Object x, Object y );

	/**
	* Y軸の最大値を取得します。
	* @return	Y軸の最大値
	*/
	public Object getYMax();

	/**
	* Y軸の最小値を取得します。
	* @return	Y軸の最小値
	*/
	public Object getYMin();

	/**
	* Y軸の値を座標値に変換します。
	* @param	rect	全体の高さ
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	* @return	座標値
	*/
	public double getYPos( Rectangle rect, Object x, Object y );

	/**
	* 格納されている系列をを適切な順序で繰り返し処理する反復子を返します。
	*/
	public Iterator	getIterator();
/*
	public Object get( Object o );
	public Object put( Object key, Object val );
*/

	/**
	* 系列を追加します。
	* @param	srs		系列を表すオブジェクト
	*/
	public void addSeries( Object srs );

	/**
	* キーの一覧を返します。
	*/
	public Map getKeys();

	/**
	* キーと値の一覧を返します。
	* @param	srs		系列を表すオブジェクト
	*/
	public Map getMapVal( Object srs );

	/**
	* データを追加します。
	* @param	srs		系列を表すオブジェクト
	* @param	x		X座標の値
	* @param	y		Y座標の値
	*/
	public void add( Object srs, Object x, Object y );

	/**
	* データを格納します。
	* keyオブジェクトは{@link Comparable}インターフェースを実装し
	* 他のキーと比較できなくてはなりません。
	* 以前にこのキーのマッピングを保持していた場合、古い値が置き換えられます。
	* @param	key		キー
	* @param	val		値
	*/
	public void add( Object key, Object val );

}

