package	jp.co.sds_corp.nanchart.graph;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Polygon;
import java.awt.Rectangle;
import java.awt.geom.Arc2D;
import java.awt.geom.Line2D;
import java.awt.geom.RectangularShape;
import java.util.Hashtable;

/**
LineGraphは、折れ線グラフを実装します。
*/
public class LineGraph extends GraphSeries
{
	/** 点の色 */
	Hashtable	hashPtCol = new Hashtable();
	/** 点のサイズ */
	int		nPtSize = 0;

	/**
	* デフォルトの状態で折れ線グラフを構築します。
	*/
	public LineGraph() {
		super();
		bArea = bStack = false;
	}

	/**
	* X軸とY軸の範囲を指定して、折れ線グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public LineGraph( double xMin, double xMax, double yMin, double yMax ) {
		super( xMin, xMax, yMin, yMax );
		bArea = bStack = false;
	}

	/**
	* X軸とY軸の範囲を指定して、折れ線グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public LineGraph( Object xMin, Object xMax, Object yMin, Object yMax ) {
		super( xMin, xMax, yMin, yMax );
		bArea = bStack = false;
	}

	/**
	* データ格納クラスを指定して、折れ線グラフを構築します。
	* @param	map		データ格納クラス
	*/
	public LineGraph( GraphStorage map ) {
		super( map );
		bArea = bStack = false;
	}

	/**
	* 点のサイズを設定します。
	* 0を指定すると、点は描画されません。
	* @param	size	点のサイズ
	*/
	public void setPointSize( int size ) {
		this.nPtSize = size;
	}

	/**
	* 設定されている点のサイズを取得します。
	* @return	点のサイズ
	*/
	public int getPointSize() {
		return this.nPtSize;
	}

	/**
	* 点の色を設定します。
	* @param	srs		系列オブジェクト
	* @param	col		表示する色
	*/
	public void setPointColor( Object srs, Color col ) {
		hashPtCol.put( srs, col );
	}

	/**
	* 点の形を取得します。
	* @param	rect	描画する矩形
	* @param	x		点のX座標を示す値
	* @param	y		点のY座標を示す値
	*/
	protected RectangularShape getPtShape( Rectangle rect,
								Object x, Object y ) {
		Arc2D		arc = new Arc2D.Double();
		Rectangle	recarc = new Rectangle();
		recarc.setRect( getXPos( rect, x, y ) - nPtSize/2,
						getYPos( rect, x, y ) - nPtSize/2,
						nPtSize, nPtSize );
		arc.setArc( recarc, 0, 360, Arc2D.OPEN );

		return arc;
	}

	/**
	* グラフ描画を行ないます。
	* @param	gr		描画するデバイス
	* @param	rect	描画する矩形
	* @param	srs		描画するグラフ
	* @param	curX	現在のX座標
	* @param	curY1	現在のY座標1
	* @param	curY2	現在のY座標2
	* @param	preX	前回のX座標
	* @param	preY1	前回のY座標1
	* @param	preY2	前回のY座標2
	*/
	public void drawPoint( Graphics2D gr, Rectangle rect, Object srs,
				Object curX, Object curY1, Object curY2,
				Object preX, Object preY1, Object preY2 )
	{
		RectangularShape	arc;
		Line2D		line = new Line2D.Double();
		int			cx, cy1, cy2;
		int			px, py1, py2;

		cx  = (int)getXPos( rect, curX, null );
		cy1 = (int )getYPos( rect, curX, curY1 );
		cy2 = (int )getYPos( rect, curX, curY2 );
		if ( preX != null ) {
			px  = (int)getXPos( rect, preX, null );
			py1 = (int )getYPos( rect, preX, preY1 );
			py2 = (int )getYPos( rect, preX, preY2 );
			if ( bArea ) {
				Polygon	pol = new Polygon();
				pol.addPoint( px, py2 );
				pol.addPoint( cx, cy2 );
				pol.addPoint( cx, cy1 );
				pol.addPoint( px, py1 );
				Color	fc = (Color )hashFillCol.get( srs );
				if ( fc == null ) {
					fc = FillCol;
				}
				if ( fc != null ) {
					gr.setColor( fc );
					gr.fill( pol );
				}
			}

			Color	lc = (Color )hashLineCol.get( srs );
			if ( lc == null ) {
				lc = LineCol;
			}
			gr.setColor( lc );
			line.setLine( px, py2, cx, cy2 );
			gr.draw( line );
		}

		if ( nPtSize > 0 ) {
			gr.setColor( (Color )hashPtCol.get( srs ) );
			arc = getPtShape( rect, curX, curY2 );
			gr.fill( arc );
		}
	}

}

