package	jp.co.sds_corp.nanchart.graph;

import java.awt.Rectangle;
import java.util.Iterator;

/**
PieStorageは、100%積み上げグラフのためのデータ格納クラスです。
<BR>
実際の値はオブジェクトの配列に格納されます。
*/
public class PieStorage extends DefaultStorage
{
	private static final long serialVersionUID = 1L;

	/**
	* デフォルトの状態でPieStorageを構築します。
	*/
	public PieStorage() {
	}

	/**
	* X軸とY軸の範囲を指定して、PieStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PieStorage( Object xMin, Object xMax, Object yMin, Object yMax ) {
		setXRange( xMin, xMax );
		setYRange( yMin, yMax );
	}

	/**
	* X軸とY軸の範囲を指定して、tackStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PieStorage( Object xMin, Object xMax, double yMin, double yMax ) {
		setXRange( xMin, xMax );
		setYRange( Double.valueOf( yMin ), Double.valueOf( yMax ));
	}

	/**
	* X軸とY軸の範囲を指定して、PieStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public PieStorage( double xMin, double xMax, double yMin, double yMax ) {
		setXRange( Double.valueOf( xMin ), Double.valueOf( xMax ));
		setYRange( Double.valueOf( yMin ), Double.valueOf( yMax ));
	}

	/**
	* 保持しているデータから、X軸の範囲を設定します。
	*/
	public void setXRange() {
		setXRange( firstKey(), lastKey() );
	}

	/**
	* 保持しているデータから、Y軸の範囲を設定します。
	*/
	public void setYRange() {
		double		dTotal = 0.0;
		Iterator	itr = keySet().iterator();
		while ( itr.hasNext() ) {
			Object	key = itr.next();
			PieData	cur = (PieData )get( key );
			dTotal += cur.getData();
		}
		setYRange( Double.valueOf( 0.0 ), Double.valueOf( dTotal ));
	}

	/**
	* X軸の値を座標値に変換します。
	* @param	rect	描画する矩形
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	* @return	座標値
	*/
	public double getXPos( Rectangle rect, Object x, Object y ) {
		return 0;
	}

	/**
	* 全体の値から角度を計算して返します。
	* @param	rect	描画する矩形
	* @param	x		格納されているキーオブジェクト
	* @param	y		格納されている値オブジェクト
	*/
	public double getYPos ( Rectangle rect, Object x, Object y ) {
		PieData	curY = (PieData )y;
		return curY.getData() / ((Number )getYMax()).doubleValue() * rect.getHeight();
	}

	/**
	* データを格納します。
	* @param	srs		系列オブジェクト
	* @param	x		X座標の値
	* @param	y		Y座標の値
	*/
	public void add( Object srs, Object x, Object y ) {
		add( x, y );
	}

	/**
	* データを格納します。
	* @param	x		X座標の値
	* @param	y		Y座標の値
	*/
	public void add( Object x, Object y ) {
		put( x, y );
	}


}

