package	jp.co.sds_corp.nanchart.graph;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Rectangle;

import jp.co.sds_corp.util.common.CmnDate;

/**
RosokuGraphは、ローソク足グラフを実装します。
<BR>
データ格納クラスに格納するデータは、X軸を表すkeyオブジェクトと
1日（期間）のデータを表現するRosokuDataでなくてはなりません。
@see    RosokuData
*/
public class RosokuGraph extends BarGraph
{
	/** 始値＜＝終値（値上り）の場合の色 */
	Color	UpCol = Color.white;
	/** 始値＞終値（値下り）の場合の色 */
	Color	DnCol = Color.black;

	/**
	* デフォルトの状態でローソク足グラフを構築します。
	*/
	public RosokuGraph() {
		setStorage( new RosokuStorage() );
	}

	/**
	* X軸とY軸の範囲を指定して、ローソク足グラフを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public RosokuGraph( CmnDate xMin, CmnDate xMax, double yMin, double yMax ) {
		setStorage( new RosokuStorage( xMin, xMax, yMin, yMax ) );
	}

	/**
	* データ格納クラスを指定して、ローソク足グラフを構築します。
	* @param	map		データ格納クラス
	*/
	public RosokuGraph( GraphStorage map )
		throws IllegalArgumentException
	{
		super( map );
		if ( !( map instanceof RosokuStorage )) {
			throw( new IllegalArgumentException( "needs RosokuStorage" ));
		}
	}

	/**
	* 値上りの色を設定します。
	* @param	col		色
	*/
	public void setUpColor( Color col ) {
		this.UpCol = col;
	}

	/**
	* 値下りの色を設定します。
	* @param	col		色
	*/
	public void setDownColor( Color col ) {
		this.DnCol = col;
	}

	/**
	* グラフ描画を行ないます。
	* @param	gr		描画するデバイス
	* @param	rect	描画する矩形
	* @param	srs		描画するグラフ
	* @param	curX	現在のX座標
	* @param	curY1	現在のY座標1
	* @param	curY2	現在のY座標2
	* @param	preX	前回のX座標
	* @param	preY1	前回のY座標1
	* @param	preY2	前回のY座標2
	*/
	public void drawPoint( Graphics2D gr, Rectangle rect, Object srs,
				Object curX, Object curY1, Object curY2,
				Object preX, Object preY1, Object preY2 )
	{
		RosokuData	val = null;
		Rectangle	recgr;
		int			y, h;
		CmnDate	key = (CmnDate)curX;
		val = (RosokuData )curY2;
		recgr = new Rectangle( (int )getXPos( rect, key, null ),
						(int )getYPos( rect, null, Double.valueOf( val.getHigh())),
						0,
						(int )( getYPos( rect, null, Double.valueOf( val.getLow()) )
								- getYPos( rect, null, Double.valueOf( val.getHigh()) )));
		gr.setColor( LineCol );
		gr.draw( recgr );
		if ( val.getStart() < val.getEnd() ) {
			gr.setColor( UpCol );
		} else {
			gr.setColor( DnCol );
		}
		if ( val.getStart() < val.getEnd() ) {
			y = (int )getYPos( rect, null, Double.valueOf( val.getEnd()) );
			h = (int )(getYPos( rect, null, Double.valueOf( val.getStart()) )
						- getYPos( rect, null, Double.valueOf( val.getEnd()) ));
		} else {
			y = (int )getYPos( rect, null, Double.valueOf( val.getStart()) );
			h = (int )(getYPos( rect, null, Double.valueOf( val.getEnd()) )
						- getYPos( rect, null, Double.valueOf( val.getStart()) ));
		}
		recgr = new Rectangle( (int )getXPos( rect, key, null )
								- nBarWidth/2,
							y, nBarWidth, h );
		gr.fill( recgr );
		gr.setColor( LineCol );
		gr.draw( recgr );
	}

}
