package	jp.co.sds_corp.nanchart.graph;

import java.util.Iterator;
import java.util.Map;

import jp.co.sds_corp.util.common.CmnDate;

/**
RosokuStorageは、ローソク足グラフのためのデータ格納クラスです。
<BR>
DefaultStorageと機能としては同等ですが、格納されるデータがRosokuDataであるため
Y軸の範囲を自動的に設定する{@link #setYRange()}のみがオーバライドされています。
*/
public class RosokuStorage extends DefaultStorage
{
	private static final long serialVersionUID = 1L;

	/**
	* デフォルトの状態でRosokuStorageを構築します。
	*/
	public RosokuStorage() {
	}

	/**
	* X軸とY軸の範囲を指定して、RosokuStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public RosokuStorage( CmnDate xMin, CmnDate xMax, double yMin, double yMax){
		super( xMin, xMax, Double.valueOf( yMin ), Double.valueOf( yMax ));
	}

	/**
	* データを追加します。
	* @param	x		日付
	* @param	high	高値
	* @param	low		安値
	* @param	start	始値
	* @param	end		終値
	*/
	public void add( CmnDate x, double high,double low,double start,double end){
		add( x, new RosokuData( x, high, low, start, end ));
	}

	/**
	* 格納されているデータから、Y軸の範囲を算出します。
	*/
	public void setYRange() {
		double		dMax = Double.NEGATIVE_INFINITY;
		Iterator	itr;
		Iterator	itrSrs;
		Map			mapKey;
		Map			mapVal;
		Object		srs;

		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				RosokuData	cur = (RosokuData )get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMax < cur.getMax() ) {
					dMax = cur.getMax();
				}
			}
		}
		double		dMin = Double.MAX_VALUE;
		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	key = itr.next();
				RosokuData	cur = (RosokuData )get( key );
				if ( cur == null ) {
					continue;
				}
				if ( dMin > cur.getMin() ) {
					dMin = cur.getMin();
				}
			}
		}
		setYRange( Double.valueOf( dMin ), Double.valueOf( dMax ));
	}

}

