package	jp.co.sds_corp.nanchart.graph;

import java.util.Iterator;
import java.util.Map;

/**
StackStorageは、積み上げグラフのためのデータ格納クラスです。
<BR>
実際の値はオブジェクトの配列に格納されます。
*/
public class StackStorage extends DefaultStorage
{
	private static final long serialVersionUID = 1L;

	/**
	* デフォルトの状態でStackStorageを構築します。
	*/
	public StackStorage() {
	}

	/**
	* X軸とY軸の範囲を指定して、StackStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public StackStorage( Object xMin, Object xMax, Object yMin, Object yMax ) {
		setXRange( xMin, xMax );
		setYRange( yMin, yMax );
	}

	/**
	* X軸とY軸の範囲を指定して、tackStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public StackStorage( Object xMin, Object xMax, double yMin, double yMax ) {
		setXRange( xMin, xMax );
		setYRange( Double.valueOf( yMin ), Double.valueOf( yMax ));
	}

	/**
	* X軸とY軸の範囲を指定して、StackStorageを構築します。
	* @param	xMin	X軸の最小値
	* @param	xMax	X軸の最大値
	* @param	yMin	Y軸の最小値
	* @param	yMax	Y軸の最大値
	*/
	public StackStorage( double xMin, double xMax, double yMin, double yMax ) {
		setXRange( Double.valueOf( xMin ), Double.valueOf( xMax ));
		setYRange( Double.valueOf( yMin ), Double.valueOf( yMax ));
	}

	protected boolean	bInit = false;
	protected DefaultStorage	mapSum = new DefaultStorage();

	/**
	* 全ての系列のデータをX軸ごとに集計します。
	*/
	protected void calcTotal() {
		Object		srs;
		Map			mapKey;
		Map			mapVal;
		Iterator	itrSrs;
		Iterator	itr;
		itrSrs = getIterator();
		while ( itrSrs.hasNext() ) {
			srs = itrSrs.next();
			mapVal = getMapVal( srs );
			mapKey = getKeys();
			itr = mapKey.keySet().iterator();
			while ( itr.hasNext() ) {
				Object	x = itr.next();
				Number	y = (Number )mapVal.get( x );
				Number	sy = (Number )mapSum.get( x );
				if ( sy == null ) {
					mapSum.put( x, y );
				} else if ( y != null ) {
					mapSum.put( x, Double.valueOf( y.doubleValue() + sy.doubleValue() ));
				}
			}
		}
	}

}

